==> odata-client-microsoft-dynamics-0.1.61-sources.jar: microsoft/dynamics/crm/complex/RetrieveAuditPartitionListResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "AuditPartitionDetailCollection"})
@JsonInclude(Include.NON_NULL)
public class RetrieveAuditPartitionListResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("AuditPartitionDetailCollection")
    protected List<AuditPartitionDetail> auditPartitionDetailCollection;

    @JsonProperty("AuditPartitionDetailCollection@nextLink")
    protected String auditPartitionDetailCollectionNextLink;

    protected RetrieveAuditPartitionListResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.RetrieveAuditPartitionListResponse";
    }

    @Property(name="AuditPartitionDetailCollection")
    @JsonIgnore
    public CollectionPage<AuditPartitionDetail> getAuditPartitionDetailCollection() {
        return new CollectionPage<AuditPartitionDetail>(contextPath, AuditPartitionDetail.class, this.auditPartitionDetailCollection, Optional.ofNullable(auditPartitionDetailCollectionNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="AuditPartitionDetailCollection")
    @JsonIgnore
    public CollectionPage<AuditPartitionDetail> getAuditPartitionDetailCollection(HttpRequestOptions options) {
        return new CollectionPage<AuditPartitionDetail>(contextPath, AuditPartitionDetail.class, this.auditPartitionDetailCollection, Optional.ofNullable(auditPartitionDetailCollectionNextLink), Collections.emptyList(), options);
    }

    public RetrieveAuditPartitionListResponse withUnmappedField(String name, String value) {
        RetrieveAuditPartitionListResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private List<AuditPartitionDetail> auditPartitionDetailCollection;
        private String auditPartitionDetailCollectionNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder auditPartitionDetailCollection(List<AuditPartitionDetail> auditPartitionDetailCollection) {
            this.auditPartitionDetailCollection = auditPartitionDetailCollection;
            this.changedFields = changedFields.add("AuditPartitionDetailCollection");
            return this;
        }

        public Builder auditPartitionDetailCollection(AuditPartitionDetail... auditPartitionDetailCollection) {
            return auditPartitionDetailCollection(Arrays.asList(auditPartitionDetailCollection));
        }

        public Builder auditPartitionDetailCollectionNextLink(String auditPartitionDetailCollectionNextLink) {
            this.auditPartitionDetailCollectionNextLink = auditPartitionDetailCollectionNextLink;
            this.changedFields = changedFields.add("AuditPartitionDetailCollection");
            return this;
        }

        public RetrieveAuditPartitionListResponse build() {
            RetrieveAuditPartitionListResponse _x = new RetrieveAuditPartitionListResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.RetrieveAuditPartitionListResponse";
            _x.auditPartitionDetailCollection = auditPartitionDetailCollection;
            _x.auditPartitionDetailCollectionNextLink = auditPartitionDetailCollectionNextLink;
            return _x;
        }
    }

    private RetrieveAuditPartitionListResponse _copy() {
        RetrieveAuditPartitionListResponse _x = new RetrieveAuditPartitionListResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.auditPartitionDetailCollection = auditPartitionDetailCollection;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RetrieveAuditPartitionListResponse[");
        b.append("AuditPartitionDetailCollection=");
        b.append(this.auditPartitionDetailCollection);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.1.93-sources.jar: microsoft/dynamics/crm/complex/RetrieveAuditPartitionListResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "AuditPartitionDetailCollection"})
@JsonInclude(Include.NON_NULL)
public class RetrieveAuditPartitionListResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("AuditPartitionDetailCollection")
    protected List<AuditPartitionDetail> auditPartitionDetailCollection;

    @JsonProperty("AuditPartitionDetailCollection@nextLink")
    protected String auditPartitionDetailCollectionNextLink;

    protected RetrieveAuditPartitionListResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.RetrieveAuditPartitionListResponse";
    }

    @Property(name="AuditPartitionDetailCollection")
    @JsonIgnore
    public CollectionPage<AuditPartitionDetail> getAuditPartitionDetailCollection() {
        return new CollectionPage<AuditPartitionDetail>(contextPath, AuditPartitionDetail.class, this.auditPartitionDetailCollection, Optional.ofNullable(auditPartitionDetailCollectionNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="AuditPartitionDetailCollection")
    @JsonIgnore
    public CollectionPage<AuditPartitionDetail> getAuditPartitionDetailCollection(HttpRequestOptions options) {
        return new CollectionPage<AuditPartitionDetail>(contextPath, AuditPartitionDetail.class, this.auditPartitionDetailCollection, Optional.ofNullable(auditPartitionDetailCollectionNextLink), Collections.emptyList(), options);
    }

    public RetrieveAuditPartitionListResponse withUnmappedField(String name, Object value) {
        RetrieveAuditPartitionListResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private List<AuditPartitionDetail> auditPartitionDetailCollection;
        private String auditPartitionDetailCollectionNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder auditPartitionDetailCollection(List<AuditPartitionDetail> auditPartitionDetailCollection) {
            this.auditPartitionDetailCollection = auditPartitionDetailCollection;
            this.changedFields = changedFields.add("AuditPartitionDetailCollection");
            return this;
        }

        public Builder auditPartitionDetailCollection(AuditPartitionDetail... auditPartitionDetailCollection) {
            return auditPartitionDetailCollection(Arrays.asList(auditPartitionDetailCollection));
        }

        public Builder auditPartitionDetailCollectionNextLink(String auditPartitionDetailCollectionNextLink) {
            this.auditPartitionDetailCollectionNextLink = auditPartitionDetailCollectionNextLink;
            this.changedFields = changedFields.add("AuditPartitionDetailCollection");
            return this;
        }

        public RetrieveAuditPartitionListResponse build() {
            RetrieveAuditPartitionListResponse _x = new RetrieveAuditPartitionListResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.RetrieveAuditPartitionListResponse";
            _x.auditPartitionDetailCollection = auditPartitionDetailCollection;
            _x.auditPartitionDetailCollectionNextLink = auditPartitionDetailCollectionNextLink;
            return _x;
        }
    }

    private RetrieveAuditPartitionListResponse _copy() {
        RetrieveAuditPartitionListResponse _x = new RetrieveAuditPartitionListResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.auditPartitionDetailCollection = auditPartitionDetailCollection;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RetrieveAuditPartitionListResponse[");
        b.append("AuditPartitionDetailCollection=");
        b.append(this.auditPartitionDetailCollection);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
